import { Descriptor } from '@abandonware/noble';
import { ConnectionState } from '@iotize/tap/protocol/api';
import { CharacteristicAdapterInterface, CharacteristicProperties, DescriptorAdapterInterface, PeripheralAdapterInterface, ServiceAdapterInterface } from '@iotize/tap/protocol/ble/common';
import { Observable } from 'rxjs';
import { Characteristic, Peripheral, Service } from './types';
export declare class PeripheralAdapter implements PeripheralAdapterInterface<ServiceAdapter> {
    private _peripheral;
    private _services;
    constructor(_peripheral: Peripheral);
    get stateChange(): Observable<ConnectionState>;
    get name(): string | undefined;
    get address(): string;
    get id(): string;
    get adapted(): Peripheral;
    get state(): string;
    private _stateChange;
    discoverServices<Key extends string = string>(serviceUUIDs?: Key[]): Promise<Partial<Record<Key, ServiceAdapter>>>;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    getService(uuid: string): Promise<ServiceAdapter>;
    private _isConnected;
}
export declare class ServiceAdapter implements ServiceAdapterInterface {
    private _service;
    _caracteristics: Record<string, CharacteristicAdapter>;
    constructor(_service: Service);
    getCharacteristics(characUUIDs?: string[]): Promise<CharacteristicAdapterInterface<DescriptorAdapterInterface>[]>;
    get uuid(): string;
    getCharacteristic(charcUUID: string): Promise<CharacteristicAdapter>;
    /**
     * @deprecated use getCharacteristics() instead
     * @param characUUIDs
     * @returns
     */
    discoverCharacteristics(characUUIDs: string[]): Promise<CharacteristicAdapter[]>;
}
export declare class CharacteristicAdapter implements CharacteristicAdapterInterface {
    private _charac;
    private _dataStream?;
    private _descriptorCache;
    get properties(): CharacteristicProperties;
    constructor(_charac: Characteristic);
    read(): Promise<Uint8Array>;
    getDescriptors(): Promise<DescriptorAdapterInterface[]>;
    get uuid(): string;
    write(data: Uint8Array, writeWithoutResponse: boolean): Promise<Uint8Array>;
    get data(): Observable<{
        data: Uint8Array;
        isNotification: boolean;
    }>;
    enableNotifications(enabled?: boolean): Promise<void>;
    private setupDataStream;
}
export declare class DescriptorAdapter implements DescriptorAdapterInterface {
    readonly descriptor: Descriptor;
    get uuid(): string;
    constructor(descriptor: Descriptor);
    writeValue(data: Uint8Array): Promise<void>;
    readValue(): Promise<Uint8Array>;
}
